==> claws-mail_3.10.1.orig.tar.xz: claws-mail-3.10.1/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[eo] Sian Mountbatten <poenikatu@fastmail.co.uk>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Colin Leroy <colin@colino.net>",
"[he] Genghis Khan <genghiskhan@gmx.ca>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id] MSulchan Darmawan <bleketux@gmail.com>",
"[lt] Mindaugas Baranauskas <embar@super.lt>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[ru] Aleksei Miheev <aleksei@miheev.info>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@gusnan.se>",
"[zh_CN] Rob <rbnwmk@gmail.com>",
"[zh_TW] Rob <rbnwmk@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Henri Bauer",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Didier Barvaux",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Pavlo Bohmat",
"Eugene Brevdo",
"Sean Buckheister",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Matthieu Dazy",
"Ben Deering",
"Pierric Descamps",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Reza Pakdel",
"Richard Palo",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Andrea Spadaccini",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};

==> claws-mail_3.11.1.orig.tar.xz: claws-mail-3.11.1/src/gtk/authors.h <==
static char *TEAM_LIST[] = {
"Holger Berndt <berndth@users.sf.net>",
"Tristan Chabredier <wwp@claws-mail.org>",
"Andrej Kacian <andrej@kacian.sk>",
"Darko Koruga <darko@users.sf.net>",
"Colin Leroy <colin@colino.net>",
"Paul Mangan <paul@claws-mail.org>",
"Ricardo Mones Lastra <ricardo@mones.org>",
"Salvatore De Paolis <iwkse@claws-mail.org>",
"Paweł Pękala <c0rn@o2.pl>",
"Michael Rasmussen <mir@datanom.net>",
NULL
};

static char *EX_TEAM_LIST[] = {
"Hoà Viêt Dinh",
"Keith Edmunds",
"Match Grun",
"Melvin Hadasht",
"Oliver Haertel",
"Christoph Hohmann",
"Alfons Hoogervorst",
"Werner Koch",
"Thorsten Maerz",
"Leandro A. F. Pereira",
"Luke Plant",
"Martin Schaaf",
"Carsten Schurig",
"Fabien Vantard",
"Sergey Vlasov",
"Hiroyuki Yamamoto",
NULL
};

static char *TRANS_TEAM_LIST[] = {
"[bg] Yasen Pramatarov <yasen@lindeas.com>",
"[cs] David Vachulka <david@konstrukce-cad.com>",
"[de] Thomas Bellmann <ThomasBellmann@gmx.net>",
"[en_GB] Paul Mangan <paul@claws-mail.org>",
"[eo] Sian Mountbatten <poenikatu@fastmail.co.uk>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fi] Flammie Pirinen <flammie@iki.fi>",
"[fr] Colin Leroy <colin@colino.net>",
"[he] Genghis Khan <genghiskhan@gmx.ca>",
"[hu] Páder Rezső <rezso@rezso.net>",
"[id] MSulchan Darmawan <bleketux@gmail.com>",
"[lt] Mindaugas Baranauskas <embar@super.lt>",
"[nb] Eyolf Østrem <eyolf@oestrem.com>",
"[pt_BR] Frederico Goncalves Guimaraes <frederico@teia.bio.br>",
"[ru] Aleksei Miheev <aleksei@miheev.info>",
"[sk] Slavko <slavino@slavino.sk>",
"[sv] Andreas Rönnquist <gusnan@gusnan.se>",
"[zh_CN] Rob <rbnwmk@gmail.com>",
"[zh_TW] Rob <rbnwmk@gmail.com>",
NULL
};

static char *DOC_TEAM_LIST[] = {
"[en] Tristan Chabredier <wwp@claws-mail.org>",
"     Ricardo Mones Lastra <ricardo@mones.org>",
"     Colin Leroy <colin@colino.net>",
"     Paul Mangan <paul@claws-mail.org>",
"[es] Ricardo Mones Lastra <ricardo@mones.org>",
"[fr] Tristan Chabredier <wwp@claws-mail.org>",
"     Colin Leroy <colin@colino.net>",
"[pl] Paweł Pękala <c0rn@gazeta.pl>",
NULL
};

static char *LOGO_LIST[] = {
"Jesper Schultz <jesper@schultz-net.dk>",
NULL
};

static char *ICONS_LIST[] = {
"Jakub 'jimmac' Steiner <jimmac@ximian.com>",
"Aleksandar Urošević <urke@users.sf.net>",
NULL
};

static char *CONTRIBS_LIST[] = {
"Alte",
"Jeremy Andrews",
"Stephen Anthony",
"André Filipe de Assunção e Brito",
"Sergei Astanin",
"Ruslan N. Balkin",
"Henri Bauer",
"Fabio Júnior Beneditto",
"M. Benkmann",
"Wilbert Berendsen",
"Didier Barvaux",
"Sébastien Bigaret",
"Laurent Bigonville",
"Jean-Luc Biord",
"Pavlo Bohmat",
"H. Merijn Brand",
"Eugene Brevdo",
"Sean Buckheister",
"Henrik Carlqvist",
"Luca Cavalli",
"David Chalmers",
"Wei-Lun Chao",
"Guillaume Chazarain",
"Tsu-Fan Cheng",
"Manrat Chobchuen",
"Rich Coe",
"Natanael Copa",
"Jonathan Corbet",
"Christian Cornelssen",
"Palmer Dabbelt",
"George Danchev",
"Kevin Day",
"Matthieu Dazy",
"Ben Deering",
"Pierric Descamps",
"Rodrigo Dias Arruda Senra",
"Frank Dietrich",
"Tim Dijkstra",
"Nicolas Doualot",
"Felix Eckhofer",
"Charles A. Edwards",
"Stefaan Eeckels",
"Mikhail Efremov",
"Willem van Engen",
"Paul Evans",
"Leonid Evdokimov",
"Xavier FACQ",
"Tiago Faria",
"Alessandro Di Federico",
"Lars Persson Fink",
"Bob Forsman",
"Matthias Förste",
"Ivan Francolin Martinez",
"Stoyan Genov",
"Stavros Giannouris",
"Thomas Gilgin",
"Marius Glauser",
"Thierry Godefroy",
"Alex Gorbachenko",
"Michał Górny",
"Bodo Graumann",
"Yang Guilong",
"Daniel Gustafson",
"HIROSHIMA",
"Oliver Haertel",
"Anders Hammar",
"Mitko Haralanov",
"Hashimoto",
"Jacob Head",
"Federico Heinz",
"Geir Helland",
"Jorge Van Hemelryck",
"Christian Hesse",
"Higuchi",
"Hiramatu",
"Marc Hoper",
"Michihide Hotta",
"Shawn Houston",
"Michael Hughes",
"Chideok Hwang",
"John E.P. Hynes",
"Hironori IWANE",
"Motonobu Ichimura",
"Alexey Illarionov",
"Yoichi Imai",
"Mathias Intemann",
"Ishihara",
"Jens Jahnke",
"Pascal Jermini",
"KAJIWARA",
"KUROSAWA",
"Nicolas Kaiser",
"Stanislav Karchebny",
"kazken3",
"WAKAI Kazunao",
"Fabian Keil",
"Martin Kluge",
"IWAMOTO Kouichi",
"Abhay S. Kushwaha",
"Joshua M. Kwan",
"Jean-Yves Lefort",
"Jérôme Lelong",
"Eric Limpens",
"Thomas Link",
"Reed Loden",
"David Looney",
"Alessandro Maestri",
"Maki",
"Jindrich Makovicka",
"Igor Mammedov",
"Tim Mann",
"HIRAMATSU Masami",
"Yasuzaki Masayoshi",
"Jason McCarver",
"Yotam Medini",
"David Mehrmann",
"Christian Mertes",
"Bram Metsch",
"Hanno Meyer-Thurow",
"George Michaelson",
"Florian Mickler",
"Neill Miller",
"Suzuki Mio",
"Alex S Moore",
"NAKAGAWA",
"Yuuki NINOMIYA",
"Satoshi Nagayasu",
"Yukihiro Nakai",
"SungHyun Nam",
"OSHIRO Naoki",
"Andrew Nelson",
"Nishika",
"Nishimura",
"Nishiyama",
"Masaaki Noro",
"Gustavo Noronha Silva",
"Ales Nosek",
"Emilian Nowak",
"James Noyes",
"Jens Oberender",
"Ofer",
"Ohmasa",
"Miquel Oliete",
"Paul Ollis",
"Fredrik Olofssen",
"Reza Pakdel",
"Richard Palo",
"Marcel Pol",
"Martin Pool",
"Quar",
"Don Quijote",
"Steve Rader",
"Jens Rantil",
"Ravemax",
"Ivan Rayner",
"David Relson",
"Volker Ribbert",
"Chad Robinson",
"Paul Rolland",
"Andreas Rönnquist",
"Luca Rosellini",
"Guy Rouillier",
"Stephan Sachse",
"Sakamoto",
"Mohammed Sameer",
"Tobias Sandhaas",
"Peter Sarvas",
"Torsten Schoenfeld",
"Simon 'corecode' Schubert",
"Kim Schulz",
"Markus Schwarzenberg",
"Setoh",
"Michael Shell",
"shigeri",
"Jesse Skinner",
"Ville Skyttä",
"Dale P. Smith",
"Andrea Spadaccini",
"Bogdan Sumanariu",
"TAKANO",
"TOGAWA",
"Tajiri",
"Takahashi",
"Tanaka",
"Shimamoto \"Neko\" Tatsuya",
"Timo Teräs",
"Pascal Terjan",
"Thorsten Thielen",
"Edgar Toernig",
"Masahiro Tomita",
"Tomita",
"Topia",
"Anders Troback",
"Tsutsui",
"Aleksandar Urošević",
"Petr Vanek",
"Jeroen Versteeg",
"Kevin Vigor",
"Botalov Vyacheslav",
"Radek Vybiral",
"Jonathan Ware",
"Watanabe",
"Rafal Weglarz",
"Martin Wicke",
"Bob Woodside",
"YAMAGUCHI",
"T. Yamamoto",
"Yanase",
"Yasumatsu",
"Ralgh Young",
"YUP",
"Gál Zoltán",
"Marien Zwart",
"Martin Zwickel",
NULL
};
